@@ -324,7 +324,7 @@ class SpaState:
             setattr(self, instance_variable_name, None)
 
     def __str__(self):
-        return str(self.properties)
+        return f"<{self.__name__}: {self.properties}>"
 
 
 class SpaWaterState(SpaState):
@@ -402,7 +402,7 @@ class SpaPump:
 class SpaLight:
     LightMode = Enum(
         "LightMode",
-        "PURPLE ORANGE RED YELLOW GREEN AQUA BLUE HIGH_SPEED_COLOR_WHEEL OFF",
+        "PURPLE ORANGE RED YELLOW GREEN AQUA BLUE HIGH_SPEED_COLOR_WHEEL FULL_DYNAMIC_RGB OFF",
     )
 
     def __init__(self, spa: Spa, **properties):
